@@ -9,4 +9,5 @@ from .sensitivity import sensitivity
 from .limit import limit
 from .MonteCarlo import MonteCarlo
 from .fft import fft
-from .two_pos_controller import .two_pos_controller
\ No newline at end of file
+from .two_pos_controller import two_pos_controller
+from .PID_controller import PID_controller
\ No newline at end of file
