@@ -73,10 +73,10 @@ def curve_fit_ode(model,
     else:
         C = df[:,col_index]
 
-    plt.figure(100)
+    plt.figure('curve fit')
     plt.grid()
-    plt.plot(xdata, ydata, 'o', markersize = 2)
-    plt.plot(t,C)
+    plt.plot(xdata, ydata, 'o', markersize = 3)
+    plt.plot(t,C,color='black')
     
     # set the default bounds
     if (bounds == None) & (guess0 != None):
@@ -94,15 +94,13 @@ def curve_fit_ode(model,
 
     # identify the index of initial condition's parameters in input guess0
     try:
-        p0 = get_index(param_var0, guess0)
-        p0_converse = get_index(guess0, param_var0)
+        p0, p0_converse = get_index(param_var0, guess0)
     except:
         pass
 
     # identify the index of ode function's parameters in input guess0
     try:
-        p1 = get_index(param, guess0)
-        p1_converse = get_index(guess0, param)
+        p1, p1_converse = get_index(param, guess0)
     except:
         pass
 
@@ -142,8 +140,8 @@ def curve_fit_ode(model,
     else:
         Cnew = df[:,col_index]
         
-    plt.figure(100)
-    plt.plot(t,Cnew)
+    plt.figure('curve fit')
+    plt.plot(t,Cnew,color='red',linestyle='dashed')
     plt.legend(["measured data","model","fitted model"])
     plt.show()
     
